@@ -1,5 +1,7 @@
 context("taxize integration")
 
+skip_on_cran()
+
 library("taxize")
 
 test_that("taxize based searches works with > 1 get_ids,
@@ -19,7 +21,6 @@ test_that("taxize based searches works with > 1 get_ids,
 	expect_is(aa, "occdat")
 	expect_is(aa$bison, "occdatind")
 	expect_equal(length(aa$bison$data), 2)
-	expect_equal(length(aa$ecoengine$data), 0)
 	expect_named(aa$bison$data, c("129313", "183327"))
 })
 
